=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2007-12-18 18:25:12 +0000
+++ bzrlib/inventory.py	2008-01-28 16:59:52 +0000
@@ -1422,7 +1422,7 @@
 
     :raises InvalidNormalization: When name is not normalized, and cannot be
         accessed on this platform by the normalized path.
-    :return: The NFC/NFKC normalised version of name.
+    :return: The NFC normalised version of name.
     """
     #------- This has been copied to bzrlib.dirstate.DirState.add, please
     # keep them synchronised.

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2007-12-27 08:25:04 +0000
+++ bzrlib/osutils.py	2008-01-28 16:59:52 +0000
@@ -360,7 +360,7 @@
 
 
 def _mac_getcwd():
-    return unicodedata.normalize('NFKC', os.getcwdu())
+    return unicodedata.normalize('NFC', os.getcwdu())
 
 
 # Default is to just use the python builtins, but these can be rebound on
@@ -1014,20 +1014,20 @@
     On platforms where the system does not normalize filenames 
     (Windows, Linux), you have to access a file by its exact path.
 
-    Internally, bzr only supports NFC/NFKC normalization, since that is 
+    Internally, bzr only supports NFC normalization, since that is 
     the standard for XML documents.
 
     So return the normalized path, and a flag indicating if the file
     can be accessed by that path.
     """
 
-    return unicodedata.normalize('NFKC', unicode(path)), True
+    return unicodedata.normalize('NFC', unicode(path)), True
 
 
 def _inaccessible_normalized_filename(path):
     __doc__ = _accessible_normalized_filename.__doc__
 
-    normalized = unicodedata.normalize('NFKC', unicode(path))
+    normalized = unicodedata.normalize('NFC', unicode(path))
     return normalized, normalized == path
 
 

=== modified file 'bzrlib/tests/test_nonascii.py'
--- bzrlib/tests/test_nonascii.py	2006-12-22 08:52:28 +0000
+++ bzrlib/tests/test_nonascii.py	2008-01-28 16:59:52 +0000
@@ -46,18 +46,26 @@
 a_dots_d = u'a\u0308'
 z_umlat_c = u'\u017d'
 z_umlat_d = u'Z\u030c'
+squared_c = u'\xbc' # This gets mapped to '2' if we use NFK[CD]
+squared_d = u'\xbc'
+quarter_c = u'\xb2' # Gets mapped to u'1\u20444' (1/4) if we use NFK[CD]
+quarter_d = u'\xb2'
 
 
 class TestNormalization(TestCase):
     """Verify that we have our normalizations correct."""
 
     def test_normalize(self):
-        self.assertEqual(a_circle_d, normalize('NFKD', a_circle_c))
-        self.assertEqual(a_circle_c, normalize('NFKC', a_circle_d))
-        self.assertEqual(a_dots_d, normalize('NFKD', a_dots_c))
-        self.assertEqual(a_dots_c, normalize('NFKC', a_dots_d))
-        self.assertEqual(z_umlat_d, normalize('NFKD', z_umlat_c))
-        self.assertEqual(z_umlat_c, normalize('NFKC', z_umlat_d))
+        self.assertEqual(a_circle_d, normalize('NFD', a_circle_c))
+        self.assertEqual(a_circle_c, normalize('NFC', a_circle_d))
+        self.assertEqual(a_dots_d, normalize('NFD', a_dots_c))
+        self.assertEqual(a_dots_c, normalize('NFC', a_dots_d))
+        self.assertEqual(z_umlat_d, normalize('NFD', z_umlat_c))
+        self.assertEqual(z_umlat_c, normalize('NFC', z_umlat_d))
+        self.assertEqual(squared_d, normalize('NFC', squared_c))
+        self.assertEqual(squared_c, normalize('NFD', squared_d))
+        self.assertEqual(quarter_d, normalize('NFC', quarter_c))
+        self.assertEqual(quarter_c, normalize('NFD', quarter_d))
 
 
 class NormalizedFilename(TestCaseWithTransport):
@@ -74,6 +82,10 @@
         self.assertEqual((a_dots_c, True), anf(a_dots_d))
         self.assertEqual((z_umlat_c, True), anf(z_umlat_c))
         self.assertEqual((z_umlat_c, True), anf(z_umlat_d))
+        self.assertEqual((squared_c, True), anf(squared_c))
+        self.assertEqual((squared_c, True), anf(squared_d))
+        self.assertEqual((quarter_c, True), anf(quarter_c))
+        self.assertEqual((quarter_c, True), anf(quarter_d))
 
     def test__inaccessible_normalized_filename(self):
         inf = osutils._inaccessible_normalized_filename
@@ -86,6 +98,10 @@
         self.assertEqual((a_dots_c, False), inf(a_dots_d))
         self.assertEqual((z_umlat_c, True), inf(z_umlat_c))
         self.assertEqual((z_umlat_c, False), inf(z_umlat_d))
+        self.assertEqual((squared_c, True), inf(squared_c))
+        self.assertEqual((squared_c, True), inf(squared_d))
+        self.assertEqual((quarter_c, True), inf(quarter_c))
+        self.assertEqual((quarter_c, True), inf(quarter_d))
 
     def test_functions(self):
         if osutils.normalizes_filenames():
@@ -121,7 +137,8 @@
         # a_circle_c and a_dots_c actually map to the same file
         # adding a suffix kicks in the 'preserving but insensitive'
         # route, and maintains the right files
-        files = [a_circle_c+'.1', a_dots_c+'.2', z_umlat_c+'.3']
+        files = [a_circle_c+'.1', a_dots_c+'.2', z_umlat_c+'.3',
+                 squared_c+'.4', quarter_c+'.5']
         try:
             self.build_tree(files, line_endings='native')
         except UnicodeError:

